==> org.eclipse.smartmdsd.xtext.system.systemDatasheet.source_1.0.0.202011021716.jar: org/eclipse/smartmdsd/xtext/system/systemDatasheet/formatting2/SystemDatasheetFormatter.java <==
/**
 * Copyright (c) 2019 Technische Hochschule Ulm, Servicerobotics Ulm, Germany
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Alex Lotz, Dennis Stampfer, Matthias Lutz
 */
package org.eclipse.smartmdsd.xtext.system.systemDatasheet.formatting2;

import java.util.Arrays;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.smartmdsd.ecore.base.genericDatasheet.DatasheetProperty;
import org.eclipse.smartmdsd.ecore.system.systemDatasheet.SystemDatasheet;
import org.eclipse.smartmdsd.xtext.base.genericDatasheet.formatting2.GenericDatasheetFormatter;
import org.eclipse.xtext.formatting2.IFormattableDocument;
import org.eclipse.xtext.formatting2.IHiddenRegionFormatter;
import org.eclipse.xtext.formatting2.regionaccess.ISemanticRegion;
import org.eclipse.xtext.resource.XtextResource;
import org.eclipse.xtext.xbase.lib.Extension;
import org.eclipse.xtext.xbase.lib.Procedures.Procedure1;

@SuppressWarnings("all")
public class SystemDatasheetFormatter extends GenericDatasheetFormatter {
  protected void _format(final SystemDatasheet systemDatasheet, @Extension final IFormattableDocument document) {
    final ISemanticRegion ropen = this.textRegionExtensions.regionFor(systemDatasheet).keyword("{");
    final ISemanticRegion rclose = this.textRegionExtensions.regionFor(systemDatasheet).keyword("}");
    final Procedure1<IHiddenRegionFormatter> _function = (IHiddenRegionFormatter it) -> {
      it.newLine();
    };
    document.prepend(ropen, _function);
    final Procedure1<IHiddenRegionFormatter> _function_1 = (IHiddenRegionFormatter it) -> {
      it.newLine();
    };
    document.append(ropen, _function_1);
    final Procedure1<IHiddenRegionFormatter> _function_2 = (IHiddenRegionFormatter it) -> {
      it.indent();
    };
    document.<ISemanticRegion, ISemanticRegion>interior(ropen, rclose, _function_2);
    final Procedure1<IHiddenRegionFormatter> _function_3 = (IHiddenRegionFormatter it) -> {
      it.newLine();
    };
    document.prepend(rclose, _function_3);
  }
  
  public void format(final Object systemDatasheet, final IFormattableDocument document) {
    if (systemDatasheet instanceof XtextResource) {
      _format((XtextResource)systemDatasheet, document);
      return;
    } else if (systemDatasheet instanceof DatasheetProperty) {
      _format((DatasheetProperty)systemDatasheet, document);
      return;
    } else if (systemDatasheet instanceof SystemDatasheet) {
      _format((SystemDatasheet)systemDatasheet, document);
      return;
    } else if (systemDatasheet instanceof EObject) {
      _format((EObject)systemDatasheet, document);
      return;
    } else if (systemDatasheet == null) {
      _format((Void)null, document);
      return;
    } else if (systemDatasheet != null) {
      _format(systemDatasheet, document);
      return;
    } else {
      throw new IllegalArgumentException("Unhandled parameter types: " +
        Arrays.<Object>asList(systemDatasheet, document).toString());
    }
  }
}

==> org.eclipse.smartmdsd.xtext.system.systemDatasheet.source_1.0.0.202110191307.jar: org/eclipse/smartmdsd/xtext/system/systemDatasheet/formatting2/SystemDatasheetFormatter.java <==
/**
 * Copyright (c) 2019 Technische Hochschule Ulm, Servicerobotics Ulm, Germany
 * headed by Prof. Dr. Christian Schlegel
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Alex Lotz, Dennis Stampfer, Matthias Lutz
 */
package org.eclipse.smartmdsd.xtext.system.systemDatasheet.formatting2;

import java.util.Arrays;
import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.smartmdsd.ecore.base.genericDatasheet.AbstractDatasheetElement;
import org.eclipse.smartmdsd.ecore.base.genericDatasheet.DatasheetProperty;
import org.eclipse.smartmdsd.ecore.system.systemDatasheet.SystemDatasheet;
import org.eclipse.smartmdsd.xtext.base.genericDatasheet.formatting2.GenericDatasheetFormatter;
import org.eclipse.xtext.formatting2.IFormattableDocument;
import org.eclipse.xtext.formatting2.IHiddenRegionFormatter;
import org.eclipse.xtext.formatting2.regionaccess.ISemanticRegion;
import org.eclipse.xtext.resource.XtextResource;
import org.eclipse.xtext.xbase.lib.Extension;
import org.eclipse.xtext.xbase.lib.Procedures.Procedure1;

@SuppressWarnings("all")
public class SystemDatasheetFormatter extends GenericDatasheetFormatter {
  protected void _format(final SystemDatasheet systemDatasheet, @Extension final IFormattableDocument document) {
    final ISemanticRegion ropen = this.textRegionExtensions.regionFor(systemDatasheet).keyword("{");
    final ISemanticRegion rclose = this.textRegionExtensions.regionFor(systemDatasheet).keyword("}");
    final Procedure1<IHiddenRegionFormatter> _function = (IHiddenRegionFormatter it) -> {
      it.newLine();
    };
    document.prepend(ropen, _function);
    final Procedure1<IHiddenRegionFormatter> _function_1 = (IHiddenRegionFormatter it) -> {
      it.newLine();
    };
    document.append(ropen, _function_1);
    final Procedure1<IHiddenRegionFormatter> _function_2 = (IHiddenRegionFormatter it) -> {
      it.indent();
    };
    document.<ISemanticRegion, ISemanticRegion>interior(ropen, rclose, _function_2);
    final Procedure1<IHiddenRegionFormatter> _function_3 = (IHiddenRegionFormatter it) -> {
      it.newLine();
    };
    document.prepend(rclose, _function_3);
    EList<AbstractDatasheetElement> _elements = systemDatasheet.getElements();
    for (final AbstractDatasheetElement element : _elements) {
      {
        document.<AbstractDatasheetElement>format(element);
        final Procedure1<IHiddenRegionFormatter> _function_4 = (IHiddenRegionFormatter it) -> {
          it.newLine();
        };
        document.<AbstractDatasheetElement>append(element, _function_4);
      }
    }
  }
  
  public void format(final Object systemDatasheet, final IFormattableDocument document) {
    if (systemDatasheet instanceof XtextResource) {
      _format((XtextResource)systemDatasheet, document);
      return;
    } else if (systemDatasheet instanceof DatasheetProperty) {
      _format((DatasheetProperty)systemDatasheet, document);
      return;
    } else if (systemDatasheet instanceof SystemDatasheet) {
      _format((SystemDatasheet)systemDatasheet, document);
      return;
    } else if (systemDatasheet instanceof EObject) {
      _format((EObject)systemDatasheet, document);
      return;
    } else if (systemDatasheet == null) {
      _format((Void)null, document);
      return;
    } else if (systemDatasheet != null) {
      _format(systemDatasheet, document);
      return;
    } else {
      throw new IllegalArgumentException("Unhandled parameter types: " +
        Arrays.<Object>asList(systemDatasheet, document).toString());
    }
  }
}
